@@ -1,9 +1,9 @@
 from dataclasses import dataclass
 
-ENCODING = 'utf-8'
+ENCODING: str = 'utf-8'
 
 # XXX use this more
-link_extract_regex = r"(https?://.+?)([ ,\n\\<>]|$)"
+link_extract_regex: str = r"(https?://.+?)([ ,\n\\<>]|$)"
 
 @dataclass
 class RAW_DATA_FILENAMES():
@@ -11,3 +11,10 @@ class RAW_DATA_FILENAMES():
     CENINFORES:     str = 'ceninfores-raw.json'
     DEFMON:         str = 'defmon-raw.json'
     GEOCONFIRMED:   str = 'geoconfirmed-raw.json'
+
+@dataclass
+class SOURCE_NAMES():
+    BELLINGCAT:     str = 'BELLINGCAT'
+    CENINFORES:     str = 'CENINFORES'
+    DEFMON:         str = 'DEFMON'
+    GEOCONFIRMED:   str = 'GEOCONFIRMED'
