@@ -1,5 +1,6 @@
 import json
 from urllib import request
+from typing import Any
 
 from .base import Downloader
 
@@ -12,7 +13,7 @@ DEFMON_ENDPOINT = 'https://widgets.scribblemaps.com/api/maps/nBT8ffpeGH/smjsonLo
 class DefmonDownloader(Downloader):
 
     @staticmethod
-    def download():
+    def download() -> Any:
         resp = request.urlopen(DEFMON_ENDPOINT)
         data = json.loads(resp.read().decode('utf-8'))
         return data
